@@ -27,15 +27,10 @@ import cuid
 from loguru import logger
 from pydantic import BaseSettings
 
+from .schemas import Chat, Config, Contact, HandsoffInfoSchema, MessageSchema
+
 # Application imports
-from .schemas import (
-    ActionToTypeEnum,
-    Chat,
-    Config,
-    Contact,
-    HandsoffInfoSchema,
-    MessageSchema,
-)
+from .types import ActionToTypeEnum
 
 
 class ChatIdTypesEnum(int, Enum):
@@ -53,6 +48,8 @@ class ChatIdTypesEnum(int, Enum):
 class WebhookTypesEnum(int, Enum):
     """Webhook types processed by this plugin
 
+    https://stackoverflow.com/questions/24487405/enum-getting-value-of-enum-on-string-conversion
+
     Args:
         int ([type]): [description]
         Enum ([type]): [description]
@@ -63,8 +60,12 @@ class WebhookTypesEnum(int, Enum):
     CHAT_QUEUED = 30
     CHAT_SESSION = 40
     CHAT_TAKEN = 50
+    CHAT_FORWARDED = 51
     MESSAGE = 60
 
+    # def __repr__(self):
+    #     return self.value
+
 
 # Acceptable medias
 MEDIA_TYPES = {
